#!/usr/bin/env python
# coding=utf-8
# connect='li233111@gmail.com'
# -*- coding: utf-8 -*-

__title__ = 'drf_jwt_wechat'
name = "drf_jwt_wechat"
__version__ = '1.11.8'
__author__ = 'liazylee'
__license__ = 'MIT'
# __copyright__ = 'Copyright 2014-2017 Blimp LLC'

# Version synonym
VERSION = __version__
